[−][src]Struct regex::bytes::SetMatches
A set of matches returned by a regex set.
Methods
impl SetMatches[src]
pub fn matched_any(&self) -> bool[src]
Whether this set contains any matches.
pub fn matched(&self, regex_index: usize) -> bool[src]
Whether the regex at the given index matched.
The index for a regex is determined by its insertion order upon the
initial construction of a RegexSet, starting at 0.
Panics
If regex_index is greater than or equal to self.len().
pub fn len(&self) -> usize[src]
The total number of regexes in the set that created these matches.
ⓘImportant traits for SetMatchesIter<'a>pub fn iter(&self) -> SetMatchesIter[src]
Returns an iterator over indexes in the regex that matched.